@@ -1,6 +1,6 @@
 package Elastic::Model::TypeMap::Base;
 {
-  $Elastic::Model::TypeMap::Base::VERSION = '0.04';
+  $Elastic::Model::TypeMap::Base::VERSION = '0.05';
 }
 
 use strict;
@@ -136,9 +136,8 @@ sub class_deflator {
         for ( keys %deflators ) {
             my $attr = $attrs->{$_};
             unless ( $attr->has_value($obj) ) {
-                next unless $attr->has_builder;
-                my $reader = $attr->get_read_method_ref;
-                $obj->$reader;
+                next unless $attr->has_builder || $attr->has_default;
+                $attr->get_read_method_ref->($obj);
             }
             my $val = $attr->get_raw_value($obj);
             eval { $hash{$_} = $deflators{$_}->($val); 1 } and next;
@@ -428,7 +427,7 @@ Elastic::Model::TypeMap::Base - A base class for all TypeMaps
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
