@@ -1,6 +1,6 @@
 package Elastic::Model::TypeMap::ES;
 {
-  $Elastic::Model::TypeMap::ES::VERSION = '0.04';
+  $Elastic::Model::TypeMap::ES::VERSION = '0.05';
 }
 
 use strict;
@@ -49,6 +49,16 @@ has_type 'Elastic::Model::Types::UID',
 
     };
 
+#===================================
+has_type 'Elastic::Model::Types::Keyword',
+#===================================
+    map_via {
+    type                         => 'string',
+    index                        => 'not_analyzed',
+    omit_norms                   => 1,
+    omit_term_freq_and_positions => 1,
+    };
+
 #===================================
 has_type 'Elastic::Model::Types::GeoPoint',
 #===================================
@@ -104,7 +114,7 @@ Elastic::Model::TypeMap::ES - Type maps for ElasticSearch-specific types
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
@@ -113,6 +123,22 @@ for ElasticSearch specific types.
 
 =head1 TYPES
 
+=head2 Elastic::Model::Types::Keyword
+
+Attributes of type L<Elastic::Model::Types/Keyword> are in/deflated
+via L<Elastic::Model::TypeMap::Moose/Any> and are mapped as:
+
+    {
+        type                         => 'string',
+        index                        => 'not_analyzed',
+        omit_norms                   => 1,
+        omit_term_freq_and_positions => 1,
+    }
+
+It is a suitable type to use for string attributes which should not
+be analyzed, and will not be used for scoring. Rather they are suitable
+to use as filters.
+
 =head2 Elastic::Model::Types::UID
 
 An L<Elastic::Model::UID> is deflated into a hash ref and reinflated
