@@ -1,11 +1,12 @@
 package Elastic::Model::Types;
 {
-  $Elastic::Model::Types::VERSION = '0.04';
+  $Elastic::Model::Types::VERSION = '0.05';
 }
 
 use strict;
 use warnings;
 use ElasticSearch();
+use ElasticSearchX::UniqueKey();
 
 use MooseX::Types::Moose qw(:all);
 use MooseX::Types::Structured qw (Dict Optional Map);
@@ -18,11 +19,13 @@ use MooseX::Types -declare => [ qw(
         CoreFieldType
         DynamicMapping
         ES
+        ES_UniqueKey
         FieldType
         GeoPoint
         HighlightArgs
         IndexMapping
         IndexNames
+        Keyword
         Latitude
         Longitude
         MultiField
@@ -90,6 +93,10 @@ coerce ES, from ArrayRef, via {
     ElasticSearch->new( servers => \@servers );
 };
 
+#===================================
+class_type ES_UniqueKey, { class => 'ElasticSearchX::UniqueKey' };
+#===================================
+
 #===================================
 subtype StoreMapping, as enum( [ 'yes', 'no' ] );
 #===================================
@@ -185,6 +192,10 @@ coerce ArrayRefOfStr, from Str, via { [$_] };
 subtype Timestamp, as Num;
 #===================================
 
+#===================================
+subtype Keyword, as Str;
+#===================================
+
 #===================================
 class_type UID, { class => 'Elastic::Model::UID' };
 #===================================
@@ -203,7 +214,7 @@ Elastic::Model::Types - MooseX::Types for general and internal use
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -222,6 +233,19 @@ use and some which will be useful generally.
 
 =head1 PUBLIC TYPES
 
+=head2 Keyword
+
+    use Elastic::Model::Types qw(Keyword);
+
+    has 'status' => (
+        is  => 'ro',
+        isa => Keyword
+    );
+
+C<Keyword> is a sub-type of C<Str>.  It is provided to make it easy to map
+string values which should not be analyzed (eg a C<status> field rather than
+a C<comment_body> field). See L<Elastic::Model::TypeMap::ES/Keyword>.
+
 =head2 Binary
 
     use Elastic::Model::Types qw(Binary);
